(
  consumer_key    => 'xxxxxxxxxxxxxxxxxxxxxxxx',
  consumer_secret => 'xxxxxxxxxx',
  access_token    => 'xxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxx',
  access_secret   => 'xxxxxxxxxxxx',
  user_id         => 'xxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxx',
);
